@@ -8,7 +8,7 @@
    or visit http://www.gnu.org/copyleft/gpl.html
 
    \file
-   \version $Id: chapters.cpp 2802 2005-02-20 18:40:37Z mosu $
+   \version $Id: chapters.cpp 2848 2005-03-06 21:43:33Z mosu $
 
    \author Written by Moritz Bunkus <moritz@bunkus.org>.
 */
@@ -35,10 +35,8 @@ string default_chapter_country;
 
 /** Is the current char an equal sign? */
 #define isequal(s) (*(s) == '=')
-/** Is the current char a colon? */
-#define iscolon(s) (*(s) == ':')
-/** Is the current char a dot? */
-#define isdot(s) (*(s) == '.')
+/** Is the current char a colon, comman or a dot? */
+#define isseparator(s) ((':' == *(s)) || (',' == *(s)) || ('.' == *(s)))
 /** Do we have two consecutive digits? */
 #define istwodigits(s) (isdigit(*(s)) && isdigit(*(s + 1)))
 /** Do we have three consecutive digits? */
@@ -53,11 +51,11 @@ string default_chapter_country;
                           istwodigits(s + 7) && \
                           isequal(s + 9) && \
                           istwodigits(s + 10) && \
-                          iscolon(s + 12) && \
+                          isseparator(s + 12) && \
                           istwodigits(s + 13) && \
-                          iscolon(s + 15) && \
+                          isseparator(s + 15) && \
                           istwodigits(s + 16) && \
-                          isdot(s + 18) && \
+                          isseparator(s + 18) && \
                           isthreedigits(s + 19))
 /** Does \c s point to a valid OGM style chapter name entry? */
 #define ischapternameline(s) ((strlen(s) >= 15) && \
@@ -442,8 +440,8 @@ parse_chapters(mm_text_io_c *in,
       return parse_xml_chapters(in, min_tc, max_tc, offset,
                                 exception_on_error);
 
-    throw error_c(mxsprintf("Unknown file format for '%s'. It does not "
-                            "contain a support chapter format.\n",
+    throw error_c(mxsprintf("Unknown chapter file format in '%s'. It does not "
+                            "contain a supported chapter format.\n",
                             in->get_file_name().c_str()));
   } catch (error_c e) {
     if (exception_on_error)
