@@ -1,21 +1,16 @@
 /*
-  mkvmerge -- utility for splicing together matroska files
-      from component media subtypes
+   mkvmerge -- utility for splicing together matroska files
+   from component media subtypes
 
-  r_ogm.h
+   Distributed under the GPL
+   see the file COPYING for details
+   or visit http://www.gnu.org/copyleft/gpl.html
 
-  Written by Moritz Bunkus <moritz@bunkus.org>
+   $Id: r_ogm.h 2809 2005-02-24 21:05:35Z mosu $
 
-  Distributed under the GPL
-  see the file COPYING for details
-  or visit http://www.gnu.org/copyleft/gpl.html
-*/
+   class definitions for the OGG media stream reader
 
-/*!
-    \file
-    \version $Id: r_ogm.h 1472 2004-02-08 22:48:19Z mosu $
-    \brief class definitions for the OGG media stream reader
-    \author Moritz Bunkus <moritz@bunkus.org>
+   Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
 #ifndef __R_OGM_H
@@ -60,7 +55,7 @@ public:
   bool done;
 
 public:
-  flac_header_extractor_c(const char *file_name, int64_t nsid);
+  flac_header_extractor_c(const string &file_name, int64_t _sid);
   ~flac_header_extractor_c();
   bool extract();
   bool read_page();
@@ -69,12 +64,11 @@ public:
 
 struct ogm_demuxer_t {
   ogg_stream_state os;
-  generic_packetizer_c *packetizer;
-  bool headers_set;
-  int sid, stype, serial, eos;
+  int ptzr;
+  int stype, serialno, eos;
   int units_processed, vorbis_rate;
-  bool headers_read;
-  char *language, *title;
+  bool headers_read, native_mode;
+  string language, title;
   vector<unsigned char *> packet_data, nh_packet_data;
   vector<int> packet_sizes, nh_packet_sizes;
 #if defined(HAVE_FLAC_FORMAT_H)
@@ -82,55 +76,53 @@ struct ogm_demuxer_t {
   int flac_header_packets, channels, bits_per_sample;
   int64_t last_granulepos;
 #endif
+  bool in_use;
 
   ogm_demuxer_t():
-    packetizer(NULL), sid(0), stype(0), serial(0), eos(0), units_processed(0),
-    vorbis_rate(0), headers_read(false), language(NULL), title(NULL) {
+    ptzr(-1), stype(0), serialno(0), eos(0), units_processed(0),
+    vorbis_rate(0), headers_read(false), native_mode(true),
+    in_use(false) {
     memset(&os, 0, sizeof(ogg_stream_state));
   }
   ~ogm_demuxer_t() {
     uint32_t i;
     for (i = 0; i < packet_data.size(); i++)
       safefree(packet_data[i]);
-    safefree(language);
-    safefree(title);
   }
 };
 
 class ogm_reader_c: public generic_reader_c {
 private:
   ogg_sync_state oy;
-  mm_io_c *mm_io;
-  int act_wchar, num_sdemuxers, nastreams, nvstreams, ntstreams, numstreams;
-  ogm_demuxer_t   **sdemuxers;
+  mm_io_c *io;
+  vector<ogm_demuxer_t *> sdemuxers;
   int bos_pages_read;
   int64_t file_size;
 
 public:
-  ogm_reader_c(track_info_c *nti) throw (error_c);
+  ogm_reader_c(track_info_c &_ti) throw (error_c);
   virtual ~ogm_reader_c();
 
-  virtual int read(generic_packetizer_c *ptzr);
-  virtual void set_headers();
+  virtual file_status_e read(generic_packetizer_c *ptzr, bool force = false);
   virtual void identify();
+  virtual void create_packetizers();
+  virtual void create_packetizer(int64_t tid);
+  virtual void add_available_track_ids();
 
-  virtual int display_priority();
-  virtual void display_progress(bool final = false);
+  virtual int get_progress();
 
-  static int probe_file(mm_io_c *mm_io, int64_t size);
+  static int probe_file(mm_io_c *io, int64_t size);
 
 private:
   virtual ogm_demuxer_t *find_demuxer(int serialno);
   virtual int read_page(ogg_page *);
-  virtual void add_new_demuxer(ogm_demuxer_t *);
   virtual void handle_new_stream(ogg_page *);
+  virtual void handle_new_stream_and_packets(ogg_page *);
   virtual void process_page(ogg_page *);
   virtual int packet_available();
   virtual int read_headers();
-  virtual void process_header_page(ogg_page *);
-  virtual void create_packetizers();
-  virtual void create_packetizer(int64_t tid);
-  virtual void free_demuxer(int);
+  virtual void process_header_page(ogg_page *pg);
+  virtual void process_header_packets(ogm_demuxer_t *dmx);
   virtual void flush_packetizers();
   virtual void handle_stream_comments();
 };
