@@ -8,7 +8,7 @@
    or visit http://www.gnu.org/copyleft/gpl.html
 
    \file
-   \version $Id: output_control.cpp 2809 2005-02-24 21:05:35Z mosu $
+   \version $Id: output_control.cpp 2844 2005-03-06 14:28:26Z mosu $
 
    \author Written by Moritz Bunkus <moritz@bunkus.org>.
    \author Modified by Steve Lhomme <steve.lhomme@free.fr>.
@@ -139,7 +139,7 @@ bool identifying = false, identify_verbose = false;
 
 cluster_helper_c *cluster_helper = NULL;
 KaxSegment *kax_segment;
-KaxTracks *kax_tracks;
+KaxTracks kax_tracks;
 KaxTrackEntry *kax_last_entry;
 KaxCues *kax_cues;
 KaxSeekHead *kax_sh_main = NULL, *kax_sh_cues = NULL;
@@ -621,30 +621,30 @@ render_headers(mm_io_c *rout) {
     if (write_meta_seek_for_clusters)
       kax_sh_cues = new KaxSeekHead();
 
-    kax_tracks = &GetChild<KaxTracks>(*kax_segment);
-    kax_last_entry = NULL;
-
-    for (i = 0; i < track_order.size(); i++)
-      if ((track_order[i].file_id >= 0) &&
-          (track_order[i].file_id < files.size()) &&
-          !files[track_order[i].file_id].appending)
-        files[track_order[i].file_id].reader->
-          set_headers_for_track(track_order[i].track_id);
-    for (i = 0; i < files.size(); i++)
-      if (!files[i].appending)
-        files[i].reader->set_headers();
-    set_timecode_scale();
-    for (i = 0; i < packetizers.size(); i++)
-      if (packetizers[i].packetizer != NULL)
-        packetizers[i].packetizer->fix_headers();
+    if (first_file) {
+      kax_last_entry = NULL;
+      for (i = 0; i < track_order.size(); i++)
+        if ((track_order[i].file_id >= 0) &&
+            (track_order[i].file_id < files.size()) &&
+            !files[track_order[i].file_id].appending)
+          files[track_order[i].file_id].reader->
+            set_headers_for_track(track_order[i].track_id);
+      for (i = 0; i < files.size(); i++)
+        if (!files[i].appending)
+          files[i].reader->set_headers();
+      set_timecode_scale();
+      for (i = 0; i < packetizers.size(); i++)
+        if (packetizers[i].packetizer != NULL)
+          packetizers[i].packetizer->fix_headers();
+    }
 
     kax_infos->Render(*rout, true);
     kax_sh_main->IndexThis(*kax_infos, *kax_segment);
 
     if (packetizers.size() > 0) {
-      kax_tracks->Render(*rout,
-                         !hack_engaged(ENGAGE_NO_DEFAULT_HEADER_VALUES));
-      kax_sh_main->IndexThis(*kax_tracks, *kax_segment);
+      kax_segment->PushElement(kax_tracks);
+      kax_tracks.Render(*rout, !hack_engaged(ENGAGE_NO_DEFAULT_HEADER_VALUES));
+      kax_sh_main->IndexThis(kax_tracks, *kax_segment);
 
       // Reserve some small amount of space for header changes by the
       // packetizers.
@@ -668,13 +668,12 @@ void
 rerender_track_headers() {
   int64_t new_void_size;
 
-  kax_tracks->UpdateSize(!hack_engaged(ENGAGE_NO_DEFAULT_HEADER_VALUES));
+  kax_tracks.UpdateSize(!hack_engaged(ENGAGE_NO_DEFAULT_HEADER_VALUES));
   new_void_size = void_after_track_headers->GetElementPosition() +
     void_after_track_headers->GetSize() -
-    kax_tracks->GetElementPosition() -
-    kax_tracks->ElementSize();
-  out->save_pos(kax_tracks->GetElementPosition());
-  kax_tracks->Render(*out, !hack_engaged(ENGAGE_NO_DEFAULT_HEADER_VALUES));
+    kax_tracks.GetElementPosition() - kax_tracks.ElementSize();
+  out->save_pos(kax_tracks.GetElementPosition());
+  kax_tracks.Render(*out, !hack_engaged(ENGAGE_NO_DEFAULT_HEADER_VALUES));
   delete void_after_track_headers;
   void_after_track_headers = new EbmlVoid;
   void_after_track_headers->SetSize(new_void_size);
@@ -1012,6 +1011,7 @@ check_append_mapping() {
   foreach(amap, append_mapping) {
     vector<generic_packetizer_c *>::const_iterator gptzr;
     generic_packetizer_c *src_ptzr, *dst_ptzr;
+    string error_message;
     int result;
 
     src_file = files.begin() + amap->src_file_id;
@@ -1030,16 +1030,23 @@ check_append_mapping() {
       die("((src_ptzr == NULL) || (dst_ptzr == NULL)). %s\n", BUGMSG);
 
     // And now try to connect the packetizers.
-    result = src_ptzr->can_connect_to(dst_ptzr);
-    if (result != CAN_CONNECT_YES)
+    result = src_ptzr->can_connect_to(dst_ptzr, error_message);
+    if (CAN_CONNECT_YES != result) {
+      string reason(result == CAN_CONNECT_NO_FORMAT ?
+                    "the formats do not match" :
+                    result == CAN_CONNECT_NO_PARAMETERS ?
+                    "the track parameters do not match" :
+                    "of unknown reasons");
+
+      if (CAN_CONNECT_NO_PARAMETERS == result)
+        reason += mxsprintf(" (%s)", error_message.c_str());
+
       mxerror("The track number %lld from the file '%s' cannot be appended "
               "to the track number %lld from the file '%s' because %s.\n",
               amap->src_track_id, files[amap->src_file_id].name.c_str(),
               amap->dst_track_id, files[amap->dst_file_id].name.c_str(),
-              result == CAN_CONNECT_NO_FORMAT ? "the formats do not match" :
-              result == CAN_CONNECT_NO_PARAMETERS ?
-              "the stream parameters do not match" :
-              "of unknown reasons");
+              reason.c_str());
+    }
     src_ptzr->connect(dst_ptzr);
     dst_file->appended_to = true;
   }
@@ -1581,6 +1588,13 @@ finish_file(bool last_file) {
     kax_segment->OverwriteHead(*out);
 
   delete out;
+
+  // The tracks element must not be deleted.
+  for (i = 0; i < kax_segment->ListSize(); ++i)
+    if (NULL == dynamic_cast<KaxTracks *>((*kax_segment)[i]))
+      delete (*kax_segment)[i];
+  kax_segment->RemoveAll();
+
   delete kax_segment;
   delete kax_cues;
   delete kax_sh_void;
@@ -1588,9 +1602,6 @@ finish_file(bool last_file) {
   delete void_after_track_headers;
   if (kax_sh_cues != NULL)
     delete kax_sh_cues;
-
-  for (i = 0; i < packetizers.size(); i++)
-    packetizers[i].packetizer->reset();
 }
 
 static void establish_deferred_connections(filelist_t &file);
