@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: pr_generic.cpp 2807 2005-02-24 14:19:32Z mosu $
+   $Id: pr_generic.cpp 2844 2005-03-06 14:28:26Z mosu $
 
    functions common for all readers/packetizers
 
@@ -567,10 +567,10 @@ generic_packetizer_c::set_headers() {
 
   if (track_entry == NULL) {
     if (kax_last_entry == NULL)
-      track_entry = &GetChild<KaxTrackEntry>(*kax_tracks);
+      track_entry = &GetChild<KaxTrackEntry>(kax_tracks);
     else
       track_entry =
-        &GetNextChild<KaxTrackEntry>(*kax_tracks, *kax_last_entry);
+        &GetNextChild<KaxTrackEntry>(kax_tracks, *kax_last_entry);
     kax_last_entry = track_entry;
     track_entry->SetGlobalTimecodeScale((int64_t)timecode_scale);
   }
