@@ -1,28 +1,24 @@
 /*
-  mkvmerge GUI -- utility for splicing together matroska files
-      from component media subtypes
+   mkvmerge GUI -- utility for splicing together matroska files
+   from component media subtypes
 
-  kax_analyzer.cpp
+   Distributed under the GPL
+   see the file COPYING for details
+   or visit http://www.gnu.org/copyleft/gpl.html
 
-  Written by Moritz Bunkus <moritz@bunkus.org>
-  Parts of this code were written by Florian Wager <flo.wagner@gmx.de>
+   $Id: kax_analyzer.cpp 2711 2005-01-12 15:03:47Z mosu $
 
-  Distributed under the GPL
-  see the file COPYING for details
-  or visit http://www.gnu.org/copyleft/gpl.html
-*/
+   Matroska file analyzer
 
-/*!
-    \file
-    \version $Id: kax_analyzer.cpp 1357 2003-12-29 22:37:57Z mosu $
-    \brief Matroska file analyzer
-    \author Moritz Bunkus <moritz@bunkus.org>
+   Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
 // The Debian g++ 3.3.1 has problems in its standard C++ headers with min
 // being defined differently. So just include these files now when min
 // has not been defined yet.
+#if __GNUC__ != 2
 #include <limits>
+#endif
 #include <iostream>
 
 #include <ebml/EbmlHead.h>
@@ -46,19 +42,19 @@ using namespace libebml;
 //            data[i]->pos, data[i]->size);
 // }
 
-kax_analyzer_c::kax_analyzer_c(wxWindow *nparent, string nname):
-  wxDialog(nparent, -1, "Analysis running", wxDefaultPosition,
+kax_analyzer_dlg_c::kax_analyzer_dlg_c(wxWindow *_parent,
+                                       mm_io_c *_file,
+                                       vector<analyzer_data_c *> &_data):
+  wxDialog(_parent, -1, wxT("Analysis running"), wxDefaultPosition,
 #ifdef SYS_WINDOWS
            wxSize(300, 130),
 #else
            wxSize(300, 100),
 #endif
-           wxCAPTION), file_name(nname), segment(NULL) {
-  try {
-    file = new mm_io_c(file_name.c_str(), MODE_SAFE);
-  } catch (...) {
-    throw error_c(string("Could not open the file " + file_name + "."));
-  }
+           wxCAPTION),
+  data(_data),
+  file(_file),
+  segment(NULL) {
 
   new wxStaticText(this, -1, _("Analyzing Matroska file"), wxPoint(10, 10));
   g_progress =
@@ -74,37 +70,12 @@ kax_analyzer_c::kax_analyzer_c(wxWindow *nparent, string nname):
 #endif
 }
 
-kax_analyzer_c::~kax_analyzer_c() {
-  uint32_t i;
-
-  delete file;
-  for (i = 0; i < data.size(); i++)
-    delete data[i];
-  if (segment != NULL)
-    delete segment;
-}
-
-bool kax_analyzer_c::probe(string file_name) {
-  try {
-    unsigned char data[4];
-    mm_io_c in(file_name.c_str(), MODE_READ);
-
-    if (in.read(data, 4) != 4)
-      return false;
-    if ((data[0] != 0x1A) || (data[1] != 0x45) ||
-        (data[2] != 0xDF) || (data[3] != 0xA3))
-      return false;
-    return true;
-  } catch (...) {
-    return false;
-  }
-}
-
 #define PFX "Not a valid Matroska file "
 #define in_parent(p) (file->getFilePointer() < \
                       (p->GetElementPosition() + p->ElementSize()))
 
-bool kax_analyzer_c::process() {
+bool
+kax_analyzer_dlg_c::process() {
   int upper_lvl_el;
   uint32_t i;
   int64_t file_size;
@@ -121,7 +92,7 @@ bool kax_analyzer_c::process() {
   l0 = es.FindNextID(EbmlHead::ClassInfos, 0xFFFFFFFFL);
   if (l0 == NULL)
     throw error_c(PFX "(no EBML head found)");
-      
+
   // Don't verify its data for now.
   l0->SkipData(es, l0->Generic().Context);
   delete l0;
@@ -153,7 +124,7 @@ bool kax_analyzer_c::process() {
                                        l1->ElementSize()));
     while (app->Pending())
       app->Dispatch();
-    
+
     l1->SkipData(es, l1->Generic().Context);
     delete l1;
     l1 = NULL;
@@ -170,8 +141,6 @@ bool kax_analyzer_c::process() {
                             0xFFFFFFFFL, true);
   } // while (l1 != NULL)
 
-  Show(false);
-
   if (l1 != NULL)
     delete l1;
 
@@ -187,8 +156,68 @@ bool kax_analyzer_c::process() {
   return true;
 }
 
-EbmlElement *kax_analyzer_c::read_element(uint32_t num,
-                                          const EbmlCallbacks &callbacks) {
+void
+kax_analyzer_dlg_c::on_abort(wxCommandEvent &evt) {
+  abort = true;
+}
+
+kax_analyzer_c::kax_analyzer_c(wxWindow *_parent,
+                               string _name):
+  file_name(_name),
+  segment(NULL) {
+  try {
+    file = new mm_file_io_c(file_name.c_str(), MODE_SAFE);
+  } catch (...) {
+    throw error_c(string("Could not open the file " + file_name + "."));
+  }
+
+  dlg = new kax_analyzer_dlg_c(_parent, file, data);
+}
+
+kax_analyzer_c::~kax_analyzer_c() {
+  uint32_t i;
+
+  delete file;
+  for (i = 0; i < data.size(); i++)
+    delete data[i];
+  if (segment != NULL)
+    delete segment;
+}
+
+bool
+kax_analyzer_c::probe(string file_name) {
+  try {
+    unsigned char data[4];
+    mm_file_io_c in(file_name.c_str());
+
+    if (in.read(data, 4) != 4)
+      return false;
+    if ((data[0] != 0x1A) || (data[1] != 0x45) ||
+        (data[2] != 0xDF) || (data[3] != 0xA3))
+      return false;
+    return true;
+  } catch (...) {
+    return false;
+  }
+}
+
+bool
+kax_analyzer_c::process() {
+  bool result;
+
+  if (dlg == NULL)
+    return false;
+
+  result = dlg->process();
+  segment = dlg->segment;
+  dlg->Destroy();
+
+  return result;
+}
+
+EbmlElement *
+kax_analyzer_c::read_element(uint32_t num,
+                             const EbmlCallbacks &callbacks) {
   EbmlElement *e;
   int upper_lvl_el;
 
@@ -208,7 +237,9 @@ EbmlElement *kax_analyzer_c::read_element(uint32_t num,
   return e;
 }
 
-void kax_analyzer_c::overwrite_elements(EbmlElement *e, int found_where) {
+void
+kax_analyzer_c::overwrite_elements(EbmlElement *e,
+                                   int found_where) {
   vector<analyzer_data_c *>::iterator dit;
   string info;
   int64_t pos, size;
@@ -305,7 +336,8 @@ void kax_analyzer_c::overwrite_elements(EbmlElement *e, int found_where) {
 //   mxinfo("overwrite_elements: %s", info.c_str());
 }
 
-bool kax_analyzer_c::update_element(EbmlElement *e) {
+bool
+kax_analyzer_c::update_element(EbmlElement *e) {
   uint32_t i, k, found_where, found_what;
   int64_t space_here, pos;
   vector<KaxSeekHead *> all_heads;
@@ -365,7 +397,7 @@ bool kax_analyzer_c::update_element(EbmlElement *e) {
       file->setFilePointer(0, seek_end);
       if (!new_segment->ForceSize(file->getFilePointer() -
                                   segment->HeadSize() -
-                                  segment->GetElementPosition())) { 
+                                  segment->GetElementPosition())) {
         segment->OverwriteHead(*file);
         wxMessageBox(_("Wrote the element at the end of the file but could "
                        "not update the segment size. Therefore the element "
@@ -603,11 +635,7 @@ bool kax_analyzer_c::update_element(EbmlElement *e) {
   return false;
 }
 
-void kax_analyzer_c::on_abort(wxCommandEvent &evt) {
-  abort = true;
-}
-
-IMPLEMENT_CLASS(kax_analyzer_c, wxDialog);
-BEGIN_EVENT_TABLE(kax_analyzer_c, wxDialog)
-  EVT_BUTTON(ID_B_ANALYZER_ABORT, kax_analyzer_c::on_abort)
+IMPLEMENT_CLASS(kax_analyzer_dlg_c, wxDialog);
+BEGIN_EVENT_TABLE(kax_analyzer_dlg_c, wxDialog)
+  EVT_BUTTON(ID_B_ANALYZER_ABORT, kax_analyzer_dlg_c::on_abort)
 END_EVENT_TABLE();
