@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: mmg.cpp 2800 2005-02-20 11:23:18Z mosu $
+   $Id: mmg.cpp 2843 2005-03-02 21:34:35Z mosu $
 
    main stuff
 
@@ -26,6 +26,7 @@
 #include "wx/clipbrd.h"
 #include "wx/config.h"
 #include "wx/datetime.h"
+#include "wx/dir.h"
 #include "wx/file.h"
 #include "wx/fileconf.h"
 #include "wx/listctrl.h"
@@ -501,9 +502,23 @@ format_date_time(time_t date_time) {
 #if defined(SYS_WINDOWS)
 wxString
 format_tooltip(const wxString &s) {
-  wxString tooltip(s);
+  static bool first = true;
+  wxString tooltip(s), nl(wxT("\n"));
+  unsigned int i;
 
-  return break_line(tooltip, 30);
+  if (!first)
+    return s;
+
+  for (i = 60; i < tooltip.length(); ++i)
+    if (wxT(' ') == tooltip[i]) {
+      first = false;
+      return tooltip.Left(i) + nl + tooltip.Right(tooltip.length() - i - 1);
+    } else if (wxT('(') == tooltip[i]) {
+      first = false;
+      return tooltip.Left(i) + nl + tooltip.Right(tooltip.length() - i);
+    }
+
+  return tooltip;
 }
 #endif
 
@@ -583,6 +598,9 @@ mmg_dialog::mmg_dialog():
 
   mdlg = this;
 
+  log_window = new wxLogWindow(this, wxT("mmg debug output"), false);
+  wxLog::SetActiveTarget(log_window);
+
   file_menu = new wxMenu();
   file_menu->Append(ID_M_FILE_NEW, wxT("&New\tCtrl-N"),
                     wxT("Start with empty settings"));
@@ -812,8 +830,14 @@ void
 mmg_dialog::on_browse_output(wxCommandEvent &evt) {
   wxFileDialog dlg(NULL, wxT("Choose an output file"), last_open_dir,
                    tc_output->GetValue().AfterLast(PSEP),
+#if wxCHECK_VERSION(2, 5, 0)
+                   wxT("Matroska A/V files (*.mka;*.mkv)|*.mkv;*.mka|"
+                       ALLFILES),
+#else
                    wxT("Matroska A/V files (*.mka;*.mkv)|*.mka;*.mkv|"
-                       ALLFILES), wxSAVE | wxOVERWRITE_PROMPT);
+                       ALLFILES),
+#endif
+                   wxSAVE | wxOVERWRITE_PROMPT);
   if(dlg.ShowModal() == wxID_OK) {
     last_open_dir = dlg.GetDirectory();
     tc_output->SetValue(dlg.GetPath());
@@ -1009,6 +1033,55 @@ mmg_dialog::set_last_chapters_in_menu(wxString name) {
   update_chapter_menu();
 }
 
+bool
+mmg_dialog::check_before_overwriting() {
+  wxFileName file_name(tc_output->GetValue());
+  wxString dir, name, ext;
+  wxArrayString files;
+  int i;
+
+  dir = file_name.GetPath(wxPATH_GET_VOLUME | wxPATH_GET_SEPARATOR);
+
+  if (!wxDir::Exists(dir)) {
+    wxMessageBox(wxT("The output directory '") + dir +
+                 wxT("' does not exist."),
+                 wxT("Directory does not exist"), wxOK | wxICON_ERROR);
+    return false;
+  }
+
+  if (!global_page->cb_split->GetValue()) {
+    if (wxFile::Exists(tc_output->GetValue()) &&
+        (wxMessageBox(wxT("The output file '") + tc_output->GetValue() +
+                      wxT("' already exists. Do you want to overwrite it?"),
+                      wxT("Overwrite existing file?"), wxYES_NO) != wxYES))
+      return false;
+    return true;
+  }
+
+  name = file_name.GetName() + wxT("-");
+  ext = file_name.GetExt();
+
+  wxDir::GetAllFiles(dir, &files, wxEmptyString, wxDIR_FILES);
+  for (i = 0; i < files.Count(); i++) {
+    wxFileName test_name(files[i]);
+
+    if (test_name.GetName().StartsWith(name) &&
+        (test_name.HasExt() == file_name.HasExt()) &&
+        (test_name.GetExt() == ext)) {
+      if (wxMessageBox(wxT("Splitting is active, and at least one of the "
+                           "potential output files '") +
+                       dir + name + wxT("*") +
+                       (file_name.HasExt() ? wxT(".") : wxEmptyString) + ext +
+                       wxT("' already exists. Do you want to overwrite them?"),
+                       wxT("Overwrite existing file(s)?"), wxYES_NO) != wxYES)
+        return false;
+      return true;
+    }
+  }
+
+  return true;
+}
+
 void
 mmg_dialog::on_run(wxCommandEvent &evt) {
   if (muxing_in_progress) {
@@ -1057,10 +1130,7 @@ mmg_dialog::on_run(wxCommandEvent &evt) {
   }
 
   if (settings_page->cb_ask_before_overwriting->IsChecked() &&
-      wxFile::Exists(tc_output->GetValue()) &&
-      (wxMessageBox(wxT("The output file '") + tc_output->GetValue() +
-                    wxT("' already exists. Do you want to overwrite it?"),
-                    wxT("Overwrite existing file?"), wxYES_NO) != wxYES))
+      !check_before_overwriting())
     return;
 
   set_on_top(false);
@@ -1263,7 +1333,7 @@ mmg_dialog::update_command_line() {
           aids += wxT(",");
         aids += sid;
 
-        if (t->aac_is_sbr) {
+        if (!t->appending && t->aac_is_sbr) {
           clargs.Add(wxT("--aac-is-sbr"));
           clargs.Add(sid);
         }
@@ -1287,12 +1357,12 @@ mmg_dialog::update_command_line() {
         }
       }
 
-      if (t->language != wxT("und")) {
+      if (!t->appending && (t->language != wxT("und"))) {
         clargs.Add(wxT("--language"));
         clargs.Add(sid + wxT(":") + extract_language_code(t->language));
       }
 
-      if (t->cues != wxT("default")) {
+      if (!t->appending && (t->cues != wxT("default"))) {
         clargs.Add(wxT("--cues"));
         if (t->cues == wxT("only for I frames"))
           clargs.Add(sid + wxT(":iframes"));
@@ -1317,41 +1387,43 @@ mmg_dialog::update_command_line() {
         clargs.Add(arg);
       }
 
-      if ((t->track_name.Length() > 0) || t->track_name_was_present) {
+      if (!t->appending &&
+          ((t->track_name.Length() > 0) || t->track_name_was_present)) {
         clargs.Add(wxT("--track-name"));
         clargs.Add(sid + wxT(":") + t->track_name);
       }
 
-      if (t->default_track) {
+      if (!t->appending && t->default_track) {
         clargs.Add(wxT("--default-track"));
         clargs.Add(sid);
       }
 
-      if (t->tags.Length() > 0) {
+      if (!t->appending && (t->tags.Length() > 0)) {
         clargs.Add(wxT("--tags"));
         clargs.Add(sid + wxT(":") + t->tags);
       }
 
-      if (!t->display_dimensions_selected && (t->aspect_ratio.Length() > 0)) {
+      if (!t->appending && !t->display_dimensions_selected &&
+          (t->aspect_ratio.Length() > 0)) {
         clargs.Add(wxT("--aspect-ratio"));
         clargs.Add(sid + wxT(":") + t->aspect_ratio);
-      } else if (t->display_dimensions_selected &&
+      } else if (!t->appending && t->display_dimensions_selected &&
                  (t->dwidth.Length() > 0) && (t->dheight.Length() > 0)) {
         clargs.Add(wxT("--display-dimensions"));
         clargs.Add(sid + wxT(":") + t->dwidth + wxT("x") + t->dheight);
       }
 
-      if (t->fourcc.Length() > 0) {
+      if (!t->appending && (t->fourcc.Length() > 0)) {
         clargs.Add(wxT("--fourcc"));
         clargs.Add(sid + wxT(":") + t->fourcc);
       }
 
-      if (t->compression.Length() > 0) {
+      if (!t->appending && (t->compression.Length() > 0)) {
         clargs.Add(wxT("--compression"));
         clargs.Add(sid + wxT(":") + t->compression);
       }
 
-      if (t->timecodes.Length() > 0) {
+      if (!t->appending && (t->timecodes.Length() > 0)) {
         clargs.Add(wxT("--timecodes"));
         clargs.Add(sid + wxT(":") + t->timecodes);
       }
@@ -1736,12 +1808,15 @@ mmg_dialog::load_job_queue() {
   if (!cfg->Read(wxT("number_of_jobs"), &num))
     return;
 
-  for (i = 0; i < jobs.size(); i++)
+  for (i = 0; i < jobs.size(); i++) {
     delete jobs[i].description;
+    delete jobs[i].log;
+  }
   jobs.clear();
 
   for (i = 0; i < num; i++) {
-    s.Printf(wxT("/jobs/%u"), i);
+    cfg->SetPath(wxT("/jobs"));
+    s.Printf(wxT("%u"), i);
     if (!cfg->HasGroup(s))
       continue;
     cfg->SetPath(s);
