@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: tab_input.cpp 2800 2005-02-20 11:23:18Z mosu $
+   $Id: tab_input.cpp 2849 2005-03-13 17:47:27Z mosu $
 
    "input" tab
 
@@ -537,7 +537,7 @@ tab_input::audio_track_mode(wxString ctype,
   cob_sub_charset->Enable(false);
   cb_default->Enable(true && !appending);
   cb_aac_is_sbr->Enable(((lctype.Find(wxT("aac")) >= 0) ||
-                         (lctype.Find(wxT("mp4a")) >= 0)) && !appending);
+                         (lctype.Find(wxT("mp4a")) >= 0)));
   tc_tags->Enable(true && !appending);
   b_browse_tags->Enable(true && !appending);
   cob_aspect_ratio->Enable(false);
@@ -710,13 +710,18 @@ tab_input::select_file(bool append) {
   media_files.Printf(wxT("Media files (%s)|%s%s|%s"), a_exts.c_str(),
                      a_exts.c_str(), rest.c_str(), wxT(ALLFILES));
   wxFileDialog dlg(NULL,
-                   append ? wxT("Choose an input file to add") :
-                   wxT("Chose an input file to append"),
-                   last_open_dir, wxT(""), media_files, wxOPEN);
+                   append ? wxT("Choose an input file to append") :
+                   wxT("Chose an input file to add"),
+                   last_open_dir, wxT(""), media_files, wxOPEN | wxMULTIPLE);
 
   if(dlg.ShowModal() == wxID_OK) {
+    wxArrayString files;
+    int i;
+
     last_open_dir = dlg.GetDirectory();
-    add_file(dlg.GetPath(), append);
+    dlg.GetPaths(files);
+    for (i = 0; i < files.Count(); i++)
+      add_file(files[i], append);
   }
 }
 
@@ -737,7 +742,7 @@ tab_input::add_file(const wxString &file_name,
   wxString name, command, id, type, exact, video_track_name, opt_file_name;
   wxArrayString output, errors;
   vector<wxString> args, pair;
-  int result, pos;
+  int result, pos, new_file_pos;
   unsigned int i, k;
   wxFile *opt_file;
   string arg_utf8;
@@ -759,7 +764,7 @@ tab_input::add_file(const wxString &file_name,
                  wxUCS(strerror(errno)));
     wxMessageBox(error, wxT("File creation failed"), wxOK | wxCENTER |
                  wxICON_ERROR);
-    throw 0;
+    return;
   }
   opt_file->Write(wxT("--output-charset\nUTF-8\n--identify-verbose\n"));
   arg_utf8 = to_utf8(file_name);
@@ -767,12 +772,23 @@ tab_input::add_file(const wxString &file_name,
   opt_file->Write(wxT("\n"));
   delete opt_file;
 
-  command = wxT("\"") + mkvmerge_path + wxT("\" @") + opt_file_name;
+  command = wxT("\"") + mkvmerge_path + wxT("\" \"@") + opt_file_name +
+    wxT("\"");
+
+  wxLogMessage(wxT("identify 1: command: ``%s''"), command.c_str());
+
   result = wxExecute(command, output, errors);
+
+  wxLogMessage(wxT("identify 1: result: %d"), result);
+  for (i = 0; i < output.Count(); i++)
+    wxLogMessage(wxT("identify 1: output[%d]: ``%s''"), i, output[i].c_str());
+  for (i = 0; i < errors.Count(); i++)
+    wxLogMessage(wxT("identify 1: errors[%d]: ``%s''"), i, errors[i].c_str());
+
   wxRemoveFile(opt_file_name);
   if ((result < 0) || (result > 1)) {
-    name.Printf(wxT("File identification failed. Return code: %d\n\n"),
-                result);
+    name.Printf(wxT("File identification failed for '%s'. Return code: "
+                    "%d\n\n"), file_name.c_str(), result);
     for (i = 0; i < output.Count(); i++)
       name += break_line(output[i]) + wxT("\n");
     name += wxT("\n");
@@ -925,10 +941,26 @@ tab_input::add_file(const wxString &file_name,
     return;
   }
 
+  // Look for a place to insert the new file. If the file is only "added",
+  // then it will be added to the back of the list. If it is "appended",
+  // then it should be inserted right after the currently selected file.
+  if (!append)
+    new_file_pos = lb_input_files->GetCount();
+  else {
+    new_file_pos = lb_input_files->GetSelection();
+    if (wxNOT_FOUND == new_file_pos)
+      new_file_pos = lb_input_files->GetCount();
+    else {
+      do {
+        ++new_file_pos;
+      } while ((files.size() > new_file_pos) && files[new_file_pos].appending);
+    }
+  }
+
   name.Printf(wxT("%s%s (%s)"), append ? wxT("++> ") : wxT(""),
               file_name.AfterLast(wxT(PSEP)).c_str(),
               file_name.BeforeLast(wxT(PSEP)).c_str());
-  lb_input_files->Append(name);
+  lb_input_files->Insert(name, new_file_pos);
 
   file.file_name = file_name;
   mdlg->set_title_maybe(file.title);
@@ -936,15 +968,25 @@ tab_input::add_file(const wxString &file_name,
     mdlg->set_title_maybe(video_track_name);
   mdlg->set_output_maybe(file.file_name);
   file.appending = append;
-  files.push_back(file);
+  files.insert(files.begin() + new_file_pos, file);
+
+  // After inserting the file the "source" index is wrong for all files
+  // after the insertion position.
+  for (i = 0; i < tracks.size(); i++)
+    if (tracks[i]->source >= new_file_pos)
+      ++tracks[i]->source;
+
+  if (name.StartsWith(wxT("++> ")))
+    name.Remove(0, 4);
+
   for (i = 0; i < file.tracks.size(); i++) {
     string format;
     wxString label;
+    int new_track_pos;
 
     mmg_track_ptr &t = file.tracks[i];
     t->enabled = true;
-    t->source = files.size() - 1;
-    tracks.push_back(t.get());
+    t->source = new_file_pos;
 
     fix_format("%s%s (ID %lld, type: %s) from %s", format);
     label.Printf(wxU(format.c_str()), t->appending ? wxT("++> ") : wxT(""),
@@ -953,8 +995,41 @@ tab_input::add_file(const wxString &file_name,
                  t->type == 'v' ? wxT("video") :
                  t->type == 's' ? wxT("subtitles") : wxT("unknown"),
                  name.c_str());
-    clb_tracks->Append(label);
-    clb_tracks->Check(clb_tracks->GetCount() - 1, true);
+
+    // Look for a place to insert this new track. If the file is "added" then
+    // the new track is simply appended to the list of existing tracks.
+    // If the file is "appended" then it should be put to the end of the
+    // chain of tracks being appended. The n'th track from this new file
+    // should be appended to the n'th track of the "old" file this new file is
+    // appended to. So first I have to find the n'th track of the "old" file.
+    // Then I have to skip over all the other tracks that are already appended
+    // to that n'th track. The insertion point is right after that.
+    if (append) {
+      int nth_old_track;
+
+      nth_old_track = 0;
+      new_track_pos = 0;
+      while ((tracks.size() > new_track_pos) && (nth_old_track < (i + 1))) {
+        if (tracks[new_track_pos]->source == (new_file_pos - 1))
+          ++nth_old_track;
+        ++new_track_pos;
+      }
+
+      // Either we've found the n'th track from the "old" file or we're at
+      // the end of the list. In the latter case we just append the track
+      // at the end and let the user figure out which track he really wants
+      // to append it to.
+      if (nth_old_track == (i + 1))
+        while ((tracks.size() > new_track_pos) &&
+               tracks[new_track_pos]->appending)
+          ++new_track_pos;
+
+    } else
+      new_track_pos = tracks.size();
+
+    tracks.insert(tracks.begin() + new_track_pos, t.get());
+    clb_tracks->Insert(label, new_track_pos);
+    clb_tracks->Check(new_track_pos, true);
   }
 
   st_tracks->Enable(true);
@@ -978,7 +1053,8 @@ tab_input::on_remove_file(wxCommandEvent &evt) {
   // Files may not be removed if something else is still being appended to
   // them.
   for (i = 0; i < (tracks.size() - 1); i++)
-    if ((tracks[i]->source == selected_file) && tracks[i + 1]->appending) {
+    if ((tracks[i]->source == selected_file) && tracks[i + 1]->appending &&
+        (tracks[i]->source != tracks[i + 1]->source)) {
       wxString err;
 
       err.Printf(wxT("The current file (number %d) cannot be removed. There "
@@ -1487,6 +1563,7 @@ tab_input::load(wxConfigBase *cfg) {
   selected_file = -1;
   selected_track = -1;
   b_remove_file->Enable(false);
+  b_append_file->Enable(false);
 
   files.clear();
   tracks.clear();
