@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: p_aac.h 2809 2005-02-24 21:05:35Z mosu $
+   $Id: p_aac.h 2842 2005-03-02 15:53:34Z mosu $
 
    class definition for the AAC output module
 
@@ -45,7 +45,8 @@ public:
   virtual const char *get_format_name() {
     return "AAC";
   }
-  virtual connection_result_e can_connect_to(generic_packetizer_c *src);
+  virtual connection_result_e can_connect_to(generic_packetizer_c *src,
+                                             string &error_message);
 
 private:
   virtual unsigned char *get_aac_packet(unsigned long *header,
