@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: p_ac3.h 2809 2005-02-24 21:05:35Z mosu $
+   $Id: p_ac3.h 2842 2005-03-02 15:53:34Z mosu $
 
    class definition for the AC3 output module
 
@@ -43,7 +43,8 @@ public:
   virtual const char *get_format_name() {
     return "AC3";
   }
-  virtual connection_result_e can_connect_to(generic_packetizer_c *src);
+  virtual connection_result_e can_connect_to(generic_packetizer_c *src,
+                                             string &error_message);
 
 protected:
   virtual unsigned char *get_ac3_packet(unsigned long *header,
