@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: p_realaudio.cpp 2809 2005-02-24 21:05:35Z mosu $
+   $Id: p_realaudio.cpp 2842 2005-03-02 15:53:34Z mosu $
 
    RealAudio output module
 
@@ -150,15 +150,15 @@ ra_packetizer_c::dump_debug_info() {
 }
 
 connection_result_e
-ra_packetizer_c::can_connect_to(generic_packetizer_c *src) {
+ra_packetizer_c::can_connect_to(generic_packetizer_c *src,
+                                string &error_message) {
   ra_packetizer_c *psrc;
 
   psrc = dynamic_cast<ra_packetizer_c *>(src);
   if (psrc == NULL)
     return CAN_CONNECT_NO_FORMAT;
-  if ((samples_per_sec != psrc->samples_per_sec) ||
-      (channels != psrc->channels) ||
-      (bits_per_sample != psrc->bits_per_sample))
-    return CAN_CONNECT_NO_PARAMETERS;
+  connect_check_a_samplerate(samples_per_sec, psrc->samples_per_sec);
+  connect_check_a_channels(channels, psrc->channels);
+  connect_check_a_bitdepth(bits_per_sample, psrc->bits_per_sample);
   return CAN_CONNECT_YES;
 }
