@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: p_textsubs.cpp 2809 2005-02-24 21:05:35Z mosu $
+   $Id: p_textsubs.cpp 2842 2005-03-02 15:53:34Z mosu $
 
    Subripper subtitle reader
 
@@ -145,7 +145,8 @@ textsubs_packetizer_c::dump_debug_info() {
 }
 
 connection_result_e
-textsubs_packetizer_c::can_connect_to(generic_packetizer_c *src) {
+textsubs_packetizer_c::can_connect_to(generic_packetizer_c *src,
+                                      string &error_message) {
   textsubs_packetizer_c *psrc;
 
   psrc = dynamic_cast<textsubs_packetizer_c *>(src);
