@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: p_video.h 2807 2005-02-24 14:19:32Z mosu $
+   $Id: p_video.h 2842 2005-03-02 15:53:34Z mosu $
 
    class definition for the video output module
 
@@ -49,7 +49,8 @@ public:
   virtual const char *get_format_name() {
     return "video";
   }
-  virtual connection_result_e can_connect_to(generic_packetizer_c *src);
+  virtual connection_result_e can_connect_to(generic_packetizer_c *src,
+                                             string &error_message);
 
 protected:
   virtual void check_fourcc();
