@@ -6,7 +6,7 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: p_vorbis.cpp 2809 2005-02-24 21:05:35Z mosu $
+   $Id: p_vorbis.cpp 2842 2005-03-02 15:53:34Z mosu $
 
    Vorbis packetizer
 
@@ -231,25 +231,22 @@ vorbis_packetizer_c::dump_debug_info() {
 }
 
 connection_result_e
-vorbis_packetizer_c::can_connect_to(generic_packetizer_c *src) {
+vorbis_packetizer_c::can_connect_to(generic_packetizer_c *src,
+                                    string &error_message) {
   vorbis_packetizer_c *vsrc;
 
   vsrc = dynamic_cast<vorbis_packetizer_c *>(src);
   if (vsrc == NULL)
     return CAN_CONNECT_NO_FORMAT;
-  if ((vi.rate != vsrc->vi.rate) || (vi.channels != vsrc->vi.channels) ||
-      (headers[0].bytes != vsrc->headers[0].bytes) ||
-      (headers[1].bytes != vsrc->headers[1].bytes) ||
-      (headers[2].bytes != vsrc->headers[2].bytes) ||
-      (headers[0].packet == NULL) ||
-      (headers[1].packet == NULL) ||
+  connect_check_a_samplerate(vi.rate, vsrc->vi.rate);
+  connect_check_a_channels(vi.channels, vsrc->vi.channels);
+  if ((headers[2].bytes != vsrc->headers[2].bytes) ||
       (headers[2].packet == NULL) ||
-      (vsrc->headers[0].packet == NULL) ||
-      (vsrc->headers[1].packet == NULL) ||
       (vsrc->headers[2].packet == NULL) ||
-      memcmp(headers[0].packet, vsrc->headers[0].packet, headers[0].bytes) ||
-      memcmp(headers[1].packet, vsrc->headers[1].packet, headers[1].bytes) ||
-      memcmp(headers[2].packet, vsrc->headers[2].packet, headers[2].bytes))
+      memcmp(headers[2].packet, vsrc->headers[2].packet, headers[2].bytes)) {
+    error_message = "The Vorbis codebooks are different; such tracks cannot "
+      "be concatenated without reencoding";
     return CAN_CONNECT_NO_PARAMETERS;
+  }
   return CAN_CONNECT_YES;
 }
